from .login import Login


class Circle(Login):
    def get_friend_circle(self, wcId: str, firstPageMd5: str = "", maxId: int = 0):
        """获取指定好友的朋友圈"""
        return super()._base_request(
            "getFriendCircle", wcId=wcId, firstPageMd5=firstPageMd5, maxId=maxId
        )

    def sns_send(self, content: str):
        """发送文字朋友圈"""
        return super()._base_request("snsSend", content=content)

    def sns_send_image(
        self, content: str, paths: str, groupUser: str = None, blackList: str = None
    ):
        """发送图片朋友圈图片
        :param content: 文本内容
        :param paths: 图片url（多个用;分隔 单张图片最大3M以内）
        :param groupUser: 对谁可见（传微信id,多个用,分隔）
        :param blackList: 对谁不可见（传微信id,多个用,分隔）
        """
        return super()._base_request(
            "snsSendImage",
            content=content,
            paths=paths,
            groupUser=groupUser,
            blackList=blackList,
        )



from .login import Login


class Send(Login):
    def send_text(self, wcId: str, content: str):
        return super()._base_request("sendText", wcId=wcId, content=content)

    def send_file(self, wcId: str, path: str, fileName: str):
        return super()._base_request(
            "sendFile", wcId=wcId, path=path, fileName=fileName
        )

    def send_image(self, wcId: str, content: str):
        return super()._base_request("sendImage2", wcId=wcId, content=content)

    def send_video(self, path: str, thumbPath: str):
        return super()._base_request("sendVideo", path=path, thumbPath=thumbPath)

    def send_url(self, wcId, title, url, description, thumbUrl):
        return super()._base_request(
            "sendUrl",
            wcId=wcId,
            title=title,
            url=url,
            description=description,
            thumbUrl=thumbUrl,
        )



from .login import Login


class Receive(Login):
    def get_msg_img(self, msgId: str, content: str, type: int = 0):
        """下载图片"""
        return super()._base_request(
            "getMsgImg", msgId=msgId, content=content, type=type
        )

    def set_http_callback_url(self, httpUrl: str, type: int):
        """设置消息接收地址
        :param type: 1:原生版 2:优化版
        """
        return super()._base_request("setHttpCallbackUrl", httpUrl=httpUrl, type=type)

    def cancel_http_callback_url(self):
        """取消消息接收"""
        return super()._base_request("cancelHttpCallbackUrl")



from .login import Login
import sys


class Address(Login):
    def init_address_list(self):
        """初始化通讯录列表，获取通讯录列表之前必须调用此接口。"""
        sys.stdout.write("初始化通讯录列表，时间较长，请耐心等待...\n")
        return super()._base_request("initAddressList")

    def get_address_list(self):
        """获取通讯录列表"""
        return super()._base_request("getAddressList")

    def get_contact(self, wcId):
        """获取联系人信息"""
        return super()._base_request("getContact", wcId=wcId)
